==> codigojaguar-0.0.6.tar.gz: lib/codigojaguar.dart <==
library jaguar;

import 'package:codigojaguar/restFunction.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';


class BotonRest extends StatefulWidget {
  /// Boton de código Jaguar con RestFunction para realizar lladamas REST a una [url]
  /// con un [metodo] y si la respuesta es true se realiza una [action].
  /// [estilo] define el estilo del boton, el [contendio] del boton, puede estar ligado a un
  /// form con un [formkey] y enseña un mensaje de error [errorStyle] cuando la respuesta es false.
  /// También se puede mostrar un [showModalLoader] con un [stringCargando].
  const BotonRest(
      {Key key,
      @required this.contenido,
      this.estilo,
      this.url,
      this.method,
      this.action,
      this.formkey,
      this.arrayData,
      this.errorStyle,
      this.showModalLoader = true,
      this.stringCargando = 'Cargando...'})
      : super(key: key);

  final Widget contenido;
  final BoxDecoration estilo;
  final String url;
  final String method;
  final Function action;
  final formkey;
  final dynamic arrayData;
  final TextStyle errorStyle;
  final bool showModalLoader;
  final String stringCargando;

  @override
  _BotonRestState createState() => _BotonRestState();
}

class _BotonRestState extends State<BotonRest> {
  bool load = false;
  bool error = false;
  String errorString = 'Algo salio mal';

  Rest restFunction = Rest();

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        error
            ? Padding(
                padding: const EdgeInsets.only(bottom: 15),
                child: Text(
                  errorString,
                  textAlign: TextAlign.center,
                  style: widget.errorStyle,
                ),
              )
            : Container(),
        Container(
          decoration: widget.estilo,
          child: Material(
            clipBehavior: Clip.hardEdge,
            color: Colors.transparent,
            child: InkWell(
              highlightColor: Colors.grey.withOpacity(0.2),
              onTap: () {
                if (!load) {
                  if (widget.formkey.currentState.validate()) {
                    widget.formkey.currentState.save();
                    setState(() {
                      load = true;
                    });
                    if (widget.showModalLoader) {
                      loadingDialog(context, widget.stringCargando);
                    }
                    restFunction
                        .restService(
                            widget.arrayData, widget.url, null, widget.method)
                        .then((serverResp) {
                      if (serverResp['status'] == 'server_true') {
                        Navigator.pop(context);
                        setState(() {
                          load = false;
                          error = false;
                        });
                        widget.action();
                      } else {
                        Navigator.pop(context);
                        setState(() {
                          load = false;
                          error = true;
                          errorString = serverResp['message'].toString();
                        });
                      }
                    });
                  }
                }
              },
              child: Container(
                  padding: EdgeInsets.symmetric(vertical: 10, horizontal: 5),
                  alignment: Alignment.center,
                  child: load
                      ? Container(
                          height: 18,
                          width: 18,
                          child: CircularProgressIndicator(
                            backgroundColor: Colors.white,
                            strokeWidth: 3,
                          ))
                      : widget.contenido),
            ),
          ),
        )
      ],
    );
  }

  loadingDialog(BuildContext context, String stringCarga) {
    AlertDialog alert = AlertDialog(
      content: WillPopScope(
        onWillPop: () {},
        child: Row(
          children: [
            CircularProgressIndicator(),
            Container(
                margin: EdgeInsets.only(left: 7),
                child: Text(stringCarga.toString())),
          ],
        ),
      ),
    );
    showDialog(
      barrierDismissible: false,
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}


class EntradaTexto extends StatefulWidget {
  final String tipo;
  final FormFieldSetter<String> onSaved;
  final FormFieldSetter<String> onChanged;
  final bool habilitado;
  final int lineasMax;
  final String valorInicial;
  final TextCapitalization textCapitalization;
  final InputDecoration estilo;
  final TextInputAction action;
  final TextInputType tipoEntrada;

  EntradaTexto(
      {Key key,
      this.tipo = 'textoCorto',
      this.onSaved,
      this.onChanged,
      this.habilitado = true,
      this.lineasMax = 1,
      this.valorInicial,
      this.textCapitalization = TextCapitalization.sentences,
      this.estilo,
      this.action = TextInputAction.next,
      this.tipoEntrada = TextInputType.name})
      : super(key: key);

  @override
  _EntradaTextoState createState() => _EntradaTextoState();
}

class _EntradaTextoState extends State<EntradaTexto> {
  Function(String) typeValidator;
  int maxCharacters;

  @override
  Widget build(BuildContext context) {
    switch (widget.tipo) {
      case "telefono":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 10) {
            return 'Ingresa un teléfono';
          } else {
            return null;
          }
        };
        maxCharacters = 20;
        break;
      case "correo":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5 || !value.contains('@')) {
            return 'Ingresa un correo';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "password":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Ingresa tu contraseña';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "nombre":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Ingresa nombre';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "apellido":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 2) {
            return 'Ingresa apellido';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "textoCorto":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 500;
        break;
      case "textoLargo":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 3000;
        break;
      case "precio":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 10;
        break;
      case "numero":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 50;
        break;
      case "opcional":
        maxCharacters = 500;
        break;
      default:
        typeValidator = (value) {
          if (value.isEmpty || value.length < 2) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 50;
    }

    return TextFormField(
      decoration: widget.estilo,
      validator: typeValidator,
      maxLength: maxCharacters,
      onSaved: widget.onSaved,
      onChanged: widget.onChanged,
      obscureText: widget.tipo == 'password' ? true : false,
      enabled: widget.habilitado,
      maxLines: widget.lineasMax,
      initialValue: widget.valorInicial,
      textCapitalization: widget.textCapitalization,
      textInputAction: widget.action,
      keyboardType: widget.tipoEntrada,
      inputFormatters: widget.tipo == 'telefono' || widget.tipo == 'numero'
          ? [
              // DecimalTextInputFormatter(),
              FilteringTextInputFormatter.allow(RegExp("[0-9 .]"))
            ]
          : null,
    );
  }
}

==> codigojaguar-0.0.7.tar.gz: lib/codigojaguar.dart <==
import 'package:codigojaguar/restFunction.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class BotonRestTest extends StatefulWidget {
  /// Boton de código Jaguar con RestFunction para realizar lladamas REST a una [url]
  /// con un [metodo] y si la respuesta es true se realiza una [action].
  /// [estilo] define el estilo del boton, el [contendio] del boton, puede estar ligado a un
  /// form con un [formkey] y enseña un mensaje de error [errorStyle] cuando la respuesta es false.
  /// También se puede mostrar un [showModalLoader] con un [stringCargando].
  const BotonRestTest(
      {Key key,
      @required this.contenido,
      this.estilo,
      this.url,
      this.method,
      // this.action,
      this.formkey,
      this.arrayData,
      this.errorStyle,
      this.showModalLoader = true,
      this.stringCargando = 'Cargando...',
      this.action})
      : super(key: key);

  final Function(dynamic) action;
  final Widget contenido;
  final BoxDecoration estilo;
  final String url;
  final String method;
  // final Function action;
  final formkey;
  final dynamic arrayData;
  final TextStyle errorStyle;
  final bool showModalLoader;
  final String stringCargando;

  @override
  _BotonRestTestState createState() => _BotonRestTestState();
}

class _BotonRestTestState extends State<BotonRestTest> {
  bool load = false;
  bool error = false;
  String errorString = 'Algo salio mal';

  Rest restFunction = Rest();

  String response;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        error
            ? Padding(
                padding: const EdgeInsets.only(bottom: 15),
                child: Text(
                  errorString,
                  textAlign: TextAlign.center,
                  style: widget.errorStyle,
                ),
              )
            : Container(),
        Container(
          decoration: widget.estilo,
          child: Material(
            clipBehavior: Clip.hardEdge,
            color: Colors.transparent,
            child: InkWell(
              highlightColor: Colors.grey.withOpacity(0.2),
              onTap: () {
                if (!load) {
                  if (widget.formkey.currentState.validate()) {
                    widget.formkey.currentState.save();
                    setState(() {
                      load = true;
                    });
                    if (widget.showModalLoader) {
                      loadingDialog(context, widget.stringCargando);
                    }
                    restFunction
                        .restService(
                            widget.arrayData, widget.url, null, widget.method)
                        .then((serverResp) {
                      setState(() {
                        response = serverResp.toString();
                      });
                      if (serverResp['status'] == 'server_true') {
                        Navigator.pop(context);
                        setState(() {
                          load = false;
                          error = false;
                        });
                        widget.action(serverResp);
                      } else {
                        Navigator.pop(context);
                        setState(() {
                          load = false;
                          error = true;
                          errorString = serverResp['message'].toString();
                        });
                      }
                    });
                  }
                }
              },
              child: Container(
                  padding: EdgeInsets.symmetric(vertical: 10, horizontal: 5),
                  alignment: Alignment.center,
                  child: load
                      ? Container(
                          height: 18,
                          width: 18,
                          child: CircularProgressIndicator(
                            backgroundColor: Colors.white,
                            strokeWidth: 3,
                          ))
                      : widget.contenido),
            ),
          ),
        )
      ],
    );
  }

  Future<String> function() async {
    return response;
  }

  loadingDialog(BuildContext context, String stringCarga) {
    AlertDialog alert = AlertDialog(
      content: WillPopScope(
        onWillPop: () {},
        child: Row(
          children: [
            CircularProgressIndicator(),
            Container(
                margin: EdgeInsets.only(left: 7),
                child: Text(stringCarga.toString())),
          ],
        ),
      ),
    );
    showDialog(
      barrierDismissible: false,
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}

class EntradaTexto extends StatefulWidget {
  final String tipo;
  final FormFieldSetter<String> onSaved;
  final FormFieldSetter<String> onChanged;
  final bool habilitado;
  final int lineasMax;
  final int longText;
  final String valorInicial;
  final TextCapitalization textCapitalization;
  final InputDecoration estilo;
  final TextInputAction action;
  final TextInputType tipoEntrada;

  EntradaTexto(
      {Key key,
      this.tipo = 'textoCorto',
      this.onSaved,
      this.onChanged,
      this.habilitado = true,
      this.lineasMax = 1,
      this.longText,
      this.valorInicial,
      this.textCapitalization = TextCapitalization.sentences,
      this.estilo,
      this.action = TextInputAction.next,
      this.tipoEntrada = TextInputType.name})
      : super(key: key);

  @override
  _EntradaTextoState createState() => _EntradaTextoState();
}

class _EntradaTextoState extends State<EntradaTexto> {
  Function(String) typeValidator;
  int maxCharacters;

  @override
  Widget build(BuildContext context) {
    switch (widget.tipo) {
      case "telefono":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 10) {
            return 'Ingresa un teléfono';
          } else {
            return null;
          }
        };
        maxCharacters = 20;
        break;
      case "correo":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5 || !value.contains('@')) {
            return 'Ingresa un correo';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "password":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Ingresa tu contraseña';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "nombre":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Ingresa nombre';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "apellido":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 2) {
            return 'Ingresa apellido';
          } else {
            return null;
          }
        };
        maxCharacters = 150;
        break;
      case "textoCorto":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 500;
        break;
      case "textoLargo":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 5) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 3000;
        break;
      case "precio":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 10;
        break;
      case "numero":
        typeValidator = (value) {
          if (value.isEmpty || value.length < 1) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 50;
        break;
      case "opcional":
        maxCharacters = 500;
        break;
      default:
        typeValidator = (value) {
          if (value.isEmpty || value.length < 2) {
            return 'Es necesario este campo';
          } else {
            return null;
          }
        };
        maxCharacters = 50;
    }

    return TextFormField(
      decoration: widget.estilo,
      validator: typeValidator,
      maxLength: widget.longText == null ? maxCharacters : widget.longText,
      onSaved: widget.onSaved,
      onChanged: widget.onChanged,
      obscureText: widget.tipo == 'password' ? true : false,
      enabled: widget.habilitado,
      maxLines: widget.lineasMax,
      initialValue: widget.valorInicial,
      textCapitalization: widget.textCapitalization,
      textInputAction: widget.action,
      keyboardType: widget.tipoEntrada,
      inputFormatters: widget.tipo == 'telefono' || widget.tipo == 'numero'
          ? [
              // DecimalTextInputFormatter(),
              FilteringTextInputFormatter.allow(RegExp("[0-9 .]"))
            ]
          : null,
    );
  }
}

class BotonSimple extends StatefulWidget {
  const BotonSimple({
    @required this.contenido,
    this.action,
    this.estilo,
  });

  final Widget contenido;
  final Function action;
  final BoxDecoration estilo;

  @override
  _BotonSimpleState createState() => _BotonSimpleState();
}

class _BotonSimpleState extends State<BotonSimple> {
  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: widget.estilo,
      child: Material(
        color: Colors.transparent,
        child: InkWell(
          highlightColor: Colors.grey.withOpacity(0.2),
          onTap: widget.action,
          child: Container(
            padding: EdgeInsets.symmetric(vertical: 10, horizontal: 5),
            alignment: Alignment.center,
            // height: 50.0,
            child: widget.contenido,
          ),
        ),
      ),
    );
  }
}
